@@ -1,5 +1,6 @@
 import datetime
 import sys
+import uuid
 
 from peewee import Model
 from flask_peewee.utils import get_dictionary_from_model
@@ -19,7 +20,9 @@ class Serializer(object):
         elif isinstance(value, datetime.time):
             return value.strftime(self.time_format)
         elif isinstance(value, Model):
-            return value.get_id()
+            return value._pk
+        elif isinstance(value, uuid.UUID):
+            return str(value)
         else:
             return value
 
