@@ -47,7 +47,9 @@ class AdminTestCase(BaseAdminTestCase):
         # check login redirect
         resp = self.app.get('/admin/')
         self.assertEqual(resp.status_code, 302)
-        self.assertTrue(resp.headers['location'].endswith('/accounts/login/?next=%2Fadmin%2F'))
+        self.assertTrue(resp.headers['location'].endswith((
+            '/accounts/login/?next=%2Fadmin%2F',
+            '/accounts/login/?next=/admin/')))
 
         # try logging in as a normal user, get a 403 forbidden
         resp = self.app.post('/accounts/login/', data={
