@@ -37,7 +37,7 @@ class PaginatedQuery(object):
 
         if isinstance(query_or_model, SelectQuery):
             self.query = query_or_model
-            self.model = self.query.model_class
+            self.model = self.query.model
         else:
             self.model = query_or_model
             self.query = self.model.select()
@@ -49,7 +49,10 @@ class PaginatedQuery(object):
         return 1
 
     def get_pages(self):
-        return int(math.ceil(float(self.query.count()) / self.paginate_by))
+        if not hasattr(self, '_get_pages'):
+            self._get_pages = int(math.ceil(
+                float(self.query.count()) / self.paginate_by))
+        return self._get_pages
 
     def get_list(self):
         return self.query.paginate(self.get_page(), self.paginate_by)
@@ -82,7 +85,7 @@ def get_dictionary_from_model(model, fields=None, exclude=None):
         if field_name in curr_exclude:
             continue
         field_obj = model_class._meta.fields[field_name]
-        field_data = model._data.get(field_name)
+        field_data = model.__data__.get(field_name)
         if isinstance(field_obj, ForeignKeyField) and field_data and field_obj.rel_model in fields:
             rel_obj = getattr(model, field_name)
             data[field_name] = get_dictionary_from_model(rel_obj, fields, exclude)
@@ -119,14 +122,14 @@ def get_model_from_dictionary(model, field_dict):
 def path_to_models(model, path):
     accum = []
     if '__' in path:
-        next, path = path.split('__')
+        attr, path = path.split('__', 1)
     else:
-        next, path = path, ''
-    if next in model._meta.rel:
-        field = model._meta.rel[next]
+        attr, path = path, ''
+    if attr in model._meta.fields:
+        field = model._meta.fields[attr]
         accum.append(field.rel_model)
     else:
-        raise AttributeError('%s has no related field named "%s"' % (model, next))
+        raise AttributeError('%s has no related field named "%s"' % (model, attr))
     if path:
         accum.extend(path_to_models(model, path))
     return accum
